function vect_flux = flux_roe(etat_l,etat_r)
% function vect_flux = flux_roe(etat_l,etat_r)
% Calcule et renvoie le flux numerique de Roe
% (Gaz parfait)

etat = etat_roe(etat_l,etat_r); % Etat interpole
c = c_lag(etat); % Vitesse du son
p = loi_etat(etat); % Pression

% Boucle sur les particules elementaires
for i=1:size(etat,2),
    
    % Valeurs propres
    val_p = [-c(1,i); 0; c(1,i)];

    % Vecteurs propres
    vect_p(:,1) = [1; c(1,i); etat(2,i).*c(1,i)-p(1,i)];
    vect_p(:,2) = [1; 0; (etat(3,i)-(etat(2,i).^2)/2)./etat(1,i)];
    vect_p(:,3) = [1; -c(1,i); -etat(2,i).*c(1,i)-p(1,i)];

    % Flux
    % Formule sous forme "pedagogique", non optimale pour les performances
    abs_jac = vect_p*abs(diag(val_p))*inv(vect_p); 
    vect_flux(:,i) = (flux_ex(etat_l(:,i)) + flux_ex(etat_r(:,i)) - abs_jac*(etat_r(:,i)-etat_l(:,i)))/2;

end